#
# spec file for package python-libarchive-c
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define requires_file() %( readlink -f '%*' | LC_ALL=C xargs -r rpm -q --qf 'Requires: %%{name} >= %%{epoch}:%%{version}\\n' -f | sed -e 's/ (none):/ /' -e 's/ 0:/ /' | grep -v "is not")

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-libarchive-c
Version:        5.1
Release:        1.2
Summary:        Python interface to libarchive
License:        CC0-1.0
Group:          Development/Languages/Python
URL:            https://github.com/Changaco/python-libarchive-c
Source:         https://files.pythonhosted.org/packages/source/l/libarchive-c/libarchive-c-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with libarchive_dynamically}
%requires_file  %{_libdir}/libarchive.so
%else
Requires:       libarchive13
%endif
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  libarchive-devel
# /SECTION
%python_subpackages

%description
A Python interface to libarchive. It uses the standard ctypes_ module to
dynamically load and access the C library.

%prep
%autosetup -p1 -n libarchive-c-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG="en_US.UTF-8"
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.md
%{python_sitelib}/*

%changelog
* Fri Mar 15 2024 Dirk Müller <dmueller@suse.com>
- update to 5.1:
  * Fix the `format_name` property and move it from the
    `ArchiveEntry` class to the `ArchiveRead` class (#127).
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0:
  * It is now possible to specify a codec for archive entry
    metadata (`pathname`, `linkpath`, `uname` and `gname`)
  * **BREAKING:** If you use the `archive_read_class` and
    `archive_write_class` arguments, the classes you provide will
    receive a codec name as a second positional argument.
  * The `timestamp_nsec` arguments of the legacy
    `ArchiveEntry.set_{a,c,m}time` methods are now optional
  * Removed obsolete dependencies (`mock` and `six`) from
    `tox.ini` (#119).
  * Always use `UTF-8` when reading the `PKG-INFO` and
    `README.rst` files (#120).
  * Replaced `pytest-xdist` with `pytest-forked` in `tox.ini`
- drop python-libarchive-c-no-mock.patch (upstream)
* Thu Jun  2 2022 Marcus Rueckert <mrueckert@suse.de>
- Hardcode libarchive13 for now until we make macro based requires
  work with the python package magic. libarchive13 was the package
  name since sle12.
* Thu Jun  2 2022 Marcus Rueckert <mrueckert@suse.de>
- we only need the shared library package for libarchive and not
  the devel package:
  use %%requires_file to get the package of the currently installed
  via the libarchive.so symlink in libarchive-devel
* Wed Mar 23 2022 pgajdos@suse.com
- version update to 4.0
  4.0
  - --
    BREAKING & SECURITY: The archive extraction functions now pass 3 security flags (SECURE_NODOTDOT, SECURE_NOABSOLUTEPATHS
    and SECURE_SYMLINKS) to libarchive by default, unless the current directory is the root.
    BREAKING: The ArchiveEntry properties atime, mtime, ctime, birthtime and size now have the value None instead of 0 when they're unset.
    BREAKING: The ArchiveEntry.pathname property now attempts to decode bytes using UTF-8. This breaks reading archives that
    contain file names which look like UTF-8 but aren't, if such a thing exists. Proper support of encodings will probably be added
    in the next version.
    Multiple entries from the same archive can now be kept in memory, however only the current entry's content can be read.
    The filetype, linkpath, size, mode, redvmajor, redvminor, uid and gid attributes of an archive entry can now be modified.
    The four time properties of archive entries now have setters, so for example entry.set_mtime(0, 0) can be replaced by entry.mtime = 0.
    Archive entries have 4 new properties: perm, rdev, uname and gname.
    When adding files to an archive, a destination path can now be specified.
    The ArchiveRead class now has a bytes_read property.
    The ArchiveWrite class now has a bytes_written property.
    Python 3.6 is no longer tested.
    The documentation has been improved.
  3.2
  - --
    This release fixes the seek callbacks passed to libarchive by the custom_reader and stream_reader function. See #116 for more details.
  3.1
  - --
  This release is mostly meant to fix #113 (a bug introduced in 3.0), but it also contains the following changes:
    the ffi.archive_error() function now returns an exception instead of raising it
    seekable_stream_reader is now an alias of stream_reader
    the misleadingly named ffi.VOID_CB function has been removed
  3.0
  - --
  Changes to the library:
    BREAKING: dropped support for Python 2.7 (#108)
    implemented reading and writing encrypted archives (#109)
    created a new context manager: seekable_stream_reader (#107)
    added support for 64-bit time_t on 32-bit systems (#101)
    load extra formats and filters when they're requested (#95)
- added patches
  fix https://github.com/Changaco/python-libarchive-c/commit/13b904e2b046db25a42cd63557d259b3d3998323
  + python-libarchive-c-no-mock.patch
- do not require mock
* Wed Apr 15 2020 pgajdos@suse.com
- version update to 2.9
  * Changes to the library:
    optimized the ArchiveEntry class (#94)
    added support for the zstd format (#90)
    fixed the top-level __all__ list (7b97d8b)
    updated the code to support Python 3.8 (#88)
    improved the add_file_from_memory method (#85 and #86)
    lowered the level of log messages from warning to info (#83)
  * Tests:
    dropped testing with Python 3.4, added 3.7 and 3.8 (#88)
    fixed unicode handling in entry tests (#84)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Jun 18 2018 9+suse@cirno.systems
- Update to version 2.8
  * add support for setting atime, ctime, mtime and birthtime
  * tell libarchive when writing an archive is aborted due to an
    exception
  * add support for getting uid and gid
  * add support for high resolution timestamps
  * add two new archive readers: stream_reader and custom_reader
  * add missing archive extraction flags
  * add the lz4 and warc formats
  * add support for write options and uid/gid lookup
* Thu Sep  7 2017 toddrme2178@gmail.com
- initial version
